@@ -1,22 +1,25 @@
 from dataclasses import asdict
 
 from dateutil.parser import parse
-from flask import abort, json, jsonify, request, send_from_directory
+from flask import abort, json, jsonify, request, send_from_directory, Blueprint
 
 from paperead.repository.materials import Material, MaterialMetadata
 
 from paperead.env import env
-from . import app
+from . import api
 
 
-@app.route("/api/materials/")
-@app.route("/api/materials/index.json")
+materials = Blueprint("materials", __name__)
+
+
+@materials.route("/")
+@materials.route("/index.json")
 def allMaterial():
     return jsonify([id for id in env.repo])
 
 
-@app.route("/api/materials/<id>/", methods=["GET"])
-@app.route("/api/materials/<id>/index.json", methods=["GET"])
+@materials.route("/<id>/", methods=["GET"])
+@materials.route("/<id>/index.json", methods=["GET"])
 def getMaterial(id: str):
     if id not in env.repo:
         abort(404)
@@ -25,7 +28,7 @@ def getMaterial(id: str):
     return jsonify(item)
 
 
-@app.route("/api/materials/<id>/", methods=["DELETE"])
+@materials.route("/<id>/", methods=["DELETE"])
 def deleteMaterial(id: str):
     if id not in env.repo:
         abort(404)
@@ -33,7 +36,7 @@ def deleteMaterial(id: str):
     return id
 
 
-@app.route("/api/materials/", methods=["POST"])
+@materials.route("/", methods=["POST"])
 def updateMaterial():
     data: dict = request.get_json()
     metadata = data.pop("metadata")
@@ -47,7 +50,7 @@ def updateMaterial():
     return obj.id
 
 
-@app.route("/api/materials/<id>/assets/<path:path>", methods=["GET"])
+@materials.route("/<id>/assets/<path:path>", methods=["GET"])
 def assets(id: str, path: str):
     if id not in env.repo:
         abort(404)
